#DETAILED SKULL SNAPS
SetOrientation 0
SetCursor 0 0 0 0

for { set slice 35 } { $slice <= 215 } { incr slice 10 } {

    SetSlice $slice
    RedrawScreen
    SaveRGB $subjdir/QA/$subject/rgb/snaps/snapshot-skull-C-$slice.rgb

}
